==> familia_0.1.tar.gz: familia/src/file/view.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _FILE_VIEW_H
#define _FILE_VIEW_H

#include <glibmm/ustring.h>
#include <gtkmm.h>

#include "position.h"
#include "boundary.h"

class FileView {
public:
  typedef FileView _Myt;
  typedef Glib::ustring _String;
  typedef Position _Position;
  typedef Boundary _Boundary;

protected:
  _String _name;
  int _scale;
  _Position _position;
  _Boundary _boundary;

public:
  _String& name();
  int& scale();
  _Position& position();
  _Boundary& boundary();
  _Myt& parse(const _String what, const _String str);
};


#endif

==> familia_0.1.2.tar.gz: familia/src/file/view.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _FILE_VIEW_H
#define _FILE_VIEW_H

#include <glibmm/ustring.h>
#include <gtkmm.h>

#include "position.h"
#include "boundary.h"

class FileView {
public:
  typedef FileView _Myt;
  typedef Glib::ustring String;
  typedef Position _Position;
  typedef Boundary _Boundary;

protected:
  String _name;
  int _scale;
  _Position _position;
  _Boundary _boundary;

public:
  String& name();
  int scale();
  _Position& position();
  _Boundary& boundary();
  _Myt& parse(const String what, const String str);
};


#endif
